pub struct SupernodalQrRef<'a, I: Index, T> { /* private fields */ }Expand description
$QR$ factors containing both the symbolic and numeric representations
Implementations
Sourceimpl<'a, I: Index, T> SupernodalQrRef<'a, I, T>
impl<'a, I: Index, T> SupernodalQrRef<'a, I, T>
Sourcepub unsafe fn new_unchecked(
symbolic: &'a SymbolicSupernodalQr<I>,
householder_row_idx: &'a [I],
tau_blocksize: &'a [I],
householder_nrows: &'a [I],
householder_ncols: &'a [I],
r_val: &'a [T],
householder_val: &'a [T],
tau_val: &'a [T],
) -> Self
pub unsafe fn new_unchecked( symbolic: &'a SymbolicSupernodalQr<I>, householder_row_idx: &'a [I], tau_blocksize: &'a [I], householder_nrows: &'a [I], householder_ncols: &'a [I], r_val: &'a [T], householder_val: &'a [T], tau_val: &'a [T], ) -> Self
creates $QR$ factors from their components
safety
the inputs must be the outputs of factorize_supernodal_numeric_qr
Sourcepub fn symbolic(self) -> &'a SymbolicSupernodalQr<I>
pub fn symbolic(self) -> &'a SymbolicSupernodalQr<I>
returns the symbolic structure of the $QR$ factorization
Sourcepub fn R_val(self) -> &'a [T]
pub fn R_val(self) -> &'a [T]
returns the numerical values of the factor $R$ of the $QR$ factorization
Sourcepub fn householder_val(self) -> &'a [T]
pub fn householder_val(self) -> &'a [T]
returns the numerical values of the householder factors of the $QR$ factorization
Sourcepub fn tau_val(self) -> &'a [T]
pub fn tau_val(self) -> &'a [T]
returns the numerical values of the $t$ factors of the $QR$ factorization
Sourcepub fn apply_Q_transpose_in_place_with_conj(
&self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
stack: &mut MemStack,
)where
T: ComplexField,
pub fn apply_Q_transpose_in_place_with_conj(
&self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
stack: &mut MemStack,
)where
T: ComplexField,
Applies $Q^{\top}$ to the rhs in place, implicitly conjugating $Q$ if needed
work is a temporary workspace with the same dimensions as rhs
Sourcepub fn solve_in_place_with_conj(
&self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
stack: &mut MemStack,
)where
T: ComplexField,
pub fn solve_in_place_with_conj(
&self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
stack: &mut MemStack,
)where
T: ComplexField,
solves the equation $A x = \text{rhs}$ in the sense of least squares, implicitly conjugating $A$ if needed
work is a temporary workspace with the same dimensions as rhs