pub struct SymbolicSupernodalHouseholder<I> { /* private fields */ }Expand description
symbolic structure of the householder reflections that compose $Q$
such that: $$ Q = (i - H_1 t_1^{-1} H_1^H) \cdot (i - H_2 t_2^{-1} H_2^H) \dots (i - H_k t_k^{-1} H_k^H)$$
Implementations
Sourceimpl<I: Index> SymbolicSupernodalHouseholder<I>
impl<I: Index> SymbolicSupernodalHouseholder<I>
Sourcepub fn n_supernodes(&self) -> usize
pub fn n_supernodes(&self) -> usize
returns the number of supernodes in the symbolic $QR$
Sourcepub fn col_ptr_for_householder_val(&self) -> &[I]
pub fn col_ptr_for_householder_val(&self) -> &[I]
returns the column pointers for the numerical values of the householder factors
Sourcepub fn col_ptr_for_tau_val(&self) -> &[I]
pub fn col_ptr_for_tau_val(&self) -> &[I]
returns the column pointers for the numerical values of the $t$ factors
Sourcepub fn col_ptr_for_householder_row_idx(&self) -> &[I]
pub fn col_ptr_for_householder_row_idx(&self) -> &[I]
returns the column pointers for the row indices of the householder factors
Sourcepub fn len_householder_val(&self) -> usize
pub fn len_householder_val(&self) -> usize
returns the length of the slice that can be used to contain the numerical values of the householder factors
Sourcepub fn len_householder_row_idx(&self) -> usize
pub fn len_householder_row_idx(&self) -> usize
returns the length of the slice that can be used to contain the row indices of the householder factors
Sourcepub fn len_tau_val(&self) -> usize
pub fn len_tau_val(&self) -> usize
returns the length of the slice that can be used to contain the numerical values of the $t$ factors