pub struct SymbolicSupernodalQr<I> { /* private fields */ }Expand description
symbolic structure of the $QR$ decomposition,
Implementations
Sourceimpl<I: Index> SymbolicSupernodalQr<I>
impl<I: Index> SymbolicSupernodalQr<I>
Sourcepub fn R_adjoint(&self) -> &SymbolicSupernodalCholesky<I>
pub fn R_adjoint(&self) -> &SymbolicSupernodalCholesky<I>
returns the symbolic structure of $R^H$
Sourcepub fn householder(&self) -> &SymbolicSupernodalHouseholder<I>
pub fn householder(&self) -> &SymbolicSupernodalHouseholder<I>
returns the symbolic structure of the householder and $t$ factors
Sourcepub fn solve_in_place_scratch<T: ComplexField>(
&self,
rhs_ncols: usize,
par: Par,
) -> StackReq
pub fn solve_in_place_scratch<T: ComplexField>( &self, rhs_ncols: usize, par: Par, ) -> StackReq
computes the size and alignment of the workspace required to solve the linear system $A x = \text{rhs}$ in the sense of least squares